# PyGMID Plugin

Use PyGMID sweep and lookup within spyder

## Build status

https://github.com/spyder-ide/spyder-boilerplate/actions?query=workflow%3A%22Win+tests%22

[![Win](https://github.com/ollghra/pygmid-plugin/workflows/Win%20tests/badge.svg)](https://github.com/ollghra/pygmid-plugin/actions?query=workflow%3A%22Win+tests%22)
[![Mac](https://github.com/ollghra/pygmid-plugin/workflows/Mac%20tests/badge.svg)](https://github.com/ollghra/pygmid-plugin/actions?query=workflow%3A%22Mac+tests%22)
[![Linux](https://github.com/ollghra/pygmid-plugin/workflows/Linux%20tests/badge.svg)](https://github.com/ollghra/pygmid-plugin/actions?query=workflow%3A%Linux+tests%22)
[![Codecov](https://codecov.io/gh/ollghra/pygmid-plugin/branch/master/graph/badge.svg)](https://codecov.io/gh/ollghra/pygmid-plugin)
[![Crowdin](https://badges.crowdin.net/pygmid-plugin/localized.svg)](https://crowdin.com/project/pygmid-plugin)
[![Docs](https://readthedocs.org/projects/pygmid-plugin/badge/?version=latest)](https://pygmid-plugin.readthedocs.io/en/latest/?badge=latest)

## Features

* TODO  
- [ ] get on pypi  
- [ ] multiple tabs  
- [ ] use cases  
- [ ] auto-label axes where ratios specified  
- [ ] issues -> FAQs or bugfix  


## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [spyder-ide/spyder5-plugin-cookiecutter](https://github.com/spyder-ide/spyder5-plugin-cookiecutter) project template.
